@@ -118,6 +118,9 @@ static void
 cb_stop_sending_data (DBusGProxy  *proxy,
 		      totemPlugin *plugin)
 {
+	if (!plugin->stream)
+		return;
+
 	D("Stop sending data signal received");
 	if (CallNPN_DestroyStreamProc (mozilla_functions.destroystream,
 				plugin->instance,
@@ -151,22 +154,6 @@ get_real_mimetype (const char *mimetype)
 	return NULL;
 }
 
-static gboolean
-is_mimetype_supported (const char *mimetype)
-{
-	const totemPluginMimeEntry *mimetypes;
-	PRUint32 count;
-
-	totemScriptablePlugin::PluginMimeTypes (&mimetypes, &count);
-
-	for (PRUint32 i = 0; i < count; ++i) {
-		if (strcmp (mimetypes[i].mimetype, mimetype) == 0)
-			return TRUE;
-	}
-
-	return FALSE;
-}
-
 static gboolean
 is_supported_scheme (const char *url)
 {
@@ -669,9 +656,6 @@ totem_plugin_new_stream (NPP instance,
 
 	D("plugin_new_stream type: %s url: %s", type, plugin->src);
 
-	if (is_mimetype_supported (type) == FALSE)
-		return NPERR_INVALID_PLUGIN_ERROR;
-
 	//FIXME need to find better semantics?
 	//what about saving the state, do we get confused?
 	if (g_str_has_prefix (plugin->src, "file://")) {
@@ -751,6 +735,11 @@ static int32 totem_plugin_write (NPP instance, NPStream *stream, int32 offset,
 	if (plugin == NULL)
 		return -1;
 
+	/* We already know it's a playlist, don't try to check it again
+	 * and just wait for it to be on-disk */
+	if (plugin->is_playlist != FALSE)
+		return len;
+
 	if (!plugin->player_pid) {
 		if (!plugin->stream) {
 			g_warning ("No stream in NPP_Write!?");
@@ -846,6 +835,13 @@ totem_plugin_url_notify (NPP instance, const char* url,
 	D("plugin_url_notify");
 }
 
+static void
+totem_plugin_print (NPP instance,
+                    NPPrint* platformPrint)
+{
+	D("plugin_print");
+}
+
 static char *
 totem_plugin_get_description (void)
 {
@@ -1052,7 +1048,7 @@ NP_Initialize (NPNetscapeFuncs * moz_funcs,
 		NewNPP_WriteReadyProc(totem_plugin_write_ready);
 	plugin_funcs->write = NewNPP_WriteProc(totem_plugin_write);
 	/* Printing ? */
-	plugin_funcs->print = NewNPP_PrintProc(NULL);
+	plugin_funcs->print = NewNPP_PrintProc(totem_plugin_print);
 	/* What's that for ? */
 	plugin_funcs->event = NewNPP_HandleEventProc(NULL);
 	plugin_funcs->urlnotify =
