@@ -1,7 +1,12 @@
 #!/bin/sh
 
 OWNER=totem
-COMMAND="totem-video-thumbnailer %u %o"
+COMMAND="$2/totem-video-thumbnailer -s %s %u %o"
+
+upd_schema()
+{
+	echo "gconftool-2 --set --type $TYPE /desktop/gnome/thumbnailers/$NAME \"$DEFAULT\"" 1>&2
+}
 
 schema()
 {
@@ -18,9 +23,12 @@ schema()
 	echo "            </locale>";
 	echo "        </schema>";
 	echo;
+
+	upd_schema;
 }
 
-MIMETYPES=`cat $1 | grep -v short_list_application_ids_for_ | grep "\/" | grep -v audio`
+MIMETYPES=`cat $1 | grep -v audio | grep -v "application/x-flac" | sed 's,+,@,'`
+MIMETYPES="$MIMETYPES audio/x-pn-realaudio"
 
 echo "<gconfschemafile>";
 echo "    <schemalist>";
@@ -39,6 +47,21 @@ for i in $MIMETYPES ; do
 	schema;
 done
 
+MIMETYPES=`cat $1 | grep -v | grep "\/" | grep audio | grep -v "audio/x-pn-realaudio"`
+
+for i in $MIMETYPES ; do
+	DIR=`echo $i | sed 's,/,@,'`
+	NAME="$DIR/enable";
+	TYPE="bool";
+	DEFAULT="false";
+	upd_schema;
+
+	NAME="$DIR/command";
+	TYPE="string";
+	DEFAULT="$COMMAND";
+	upd_schema;
+done
+
 echo "    </schemalist>";
 echo "</gconfschemafile>"
     
