@@ -77,6 +77,7 @@ struct Totem {
 	/* Sidebar */
 	GtkWidget *sidebar;
 	gboolean sidebar_shown;
+	int sidebar_w;
 
 	/* Separate Dialogs */
 	GtkWidget *properties;
@@ -143,6 +144,10 @@ struct Totem {
 	gint64 seek_to;
 	guint index;
 
+	/* Window State */
+	int window_w, window_h;
+	gboolean maximised;
+
 	/* other */
 	char *mrl;
 	TotemPlaylist *playlist;
