@@ -131,7 +131,8 @@ totem_statusbar_init (TotemStatusbar *statusbar)
   gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (statusbar->progress),
 				    GTK_ORIENTATION_HORIZONTAL);
   gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (statusbar->progress), 0.);
-  gtk_box_pack_start (GTK_BOX (hbox), statusbar->progress, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), statusbar->progress, FALSE, TRUE, 0);
+  gtk_widget_set_size_request (statusbar->progress, 150, 10);
   gtk_widget_hide (statusbar->progress);
 
   packer = gtk_vseparator_new ();
@@ -155,6 +156,19 @@ totem_statusbar_new (void)
   return g_object_new (TOTEM_TYPE_STATUSBAR, NULL);
 }
 
+GtkWidget *
+totem_statusbar_new_from_glade (gchar *widget_name,
+		gchar *string1, gchar *string2,
+		gint int1, gint int2)
+{
+	GtkWidget *widget;
+
+	widget = totem_statusbar_new ();
+	gtk_widget_show (widget);
+
+	return widget;
+}
+
 static void
 totem_statusbar_update_time (TotemStatusbar *statusbar)
 {
@@ -188,6 +202,8 @@ void
 totem_statusbar_set_text (TotemStatusbar *statusbar, const char *label)
 {
   gtk_label_set_text (GTK_LABEL (statusbar->label), label);
+  g_free (statusbar->saved_label);
+  statusbar->saved_label = g_strdup (label);
 }
 
 void
@@ -391,6 +407,12 @@ totem_statusbar_create_window (TotemStatusbar *statusbar)
   statusbar->grip_window = gdk_window_new (widget->window,
                                            &attributes, attributes_mask);
   gdk_window_set_user_data (statusbar->grip_window, widget);
+
+  if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
+    statusbar->cursor = gdk_cursor_new (GDK_BOTTOM_LEFT_CORNER);
+  else
+    statusbar->cursor = gdk_cursor_new (GDK_BOTTOM_RIGHT_CORNER);
+  gdk_window_set_cursor (statusbar->grip_window, statusbar->cursor);
 }
 
 static void
@@ -398,6 +420,8 @@ totem_statusbar_destroy_window (TotemStatusbar *statusbar)
 {
   gdk_window_set_user_data (statusbar->grip_window, NULL);
   gdk_window_destroy (statusbar->grip_window);
+  gdk_cursor_unref (statusbar->cursor);
+  statusbar->cursor = NULL;
   statusbar->grip_window = NULL;
 }
 
@@ -539,7 +563,7 @@ totem_statusbar_size_request   (GtkWidget      *widget,
 
   gtk_widget_style_get (GTK_WIDGET (statusbar), "shadow_type", &shadow_type, NULL);  
   gtk_frame_set_shadow_type (GTK_FRAME (statusbar->frame), shadow_type);
-  
+
   GTK_WIDGET_CLASS (parent_class)->size_request (widget, requisition);
 
   if (statusbar->has_resize_grip)
